@@ -1,5 +1,4 @@
-from ast import Mult, parse
-from rest_framework import viewsets, permissions, views, parsers
+from rest_framework import viewsets, permissions, views
 from rest_framework.response import Response
 
 from .models import FileModel
@@ -9,7 +8,6 @@ from .serializers import FileSerializer
 class FileViewSet(viewsets.ModelViewSet):
     queryset = FileModel.objects.all()
     serializer_class = FileSerializer
-    # parser_classes = [parsers.MultiPartParser, parsers.FormParser]
 
     def get_permissions(self):
         if self.action in ('list', 'retrieve'):
@@ -20,9 +18,6 @@ class FileViewSet(viewsets.ModelViewSet):
             return [permissions.IsAuthenticated()]
 
     def create(self, request, *args, **kwargs):
-        print(request.FILES)
-
-        
         return super().create(request, *args, **kwargs)
 
     def destroy(self, request, *args, **kwargs):
